@@ -42,18 +42,18 @@ typedef unsigned int guint32;
 #define G_GUINT32_FORMAT "u"
 #define G_HAVE_GINT64 1          /* deprecated, always true */
 
-G_GNUC_EXTENSION typedef signed long long gint64;
-G_GNUC_EXTENSION typedef unsigned long long guint64;
+typedef signed long gint64;
+typedef unsigned long guint64;
 
-#define G_GINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##LL))
-#define G_GUINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##ULL))
-#define G_GINT64_MODIFIER "ll"
-#define G_GINT64_FORMAT "lli"
-#define G_GUINT64_FORMAT "llu"
+#define G_GINT64_CONSTANT(val)	(val##L)
+#define G_GUINT64_CONSTANT(val)	(val##UL)
+#define G_GINT64_MODIFIER "l"
+#define G_GINT64_FORMAT "li"
+#define G_GUINT64_FORMAT "lu"
 
-#define GLIB_SIZEOF_VOID_P 4
-#define GLIB_SIZEOF_LONG   4
-#define GLIB_SIZEOF_SIZE_T 4
+#define GLIB_SIZEOF_VOID_P 8
+#define GLIB_SIZEOF_LONG   8
+#define GLIB_SIZEOF_SIZE_T 8
 
 typedef signed long gssize;
 typedef unsigned long gsize;
@@ -70,11 +70,11 @@ typedef gint64 goffset;
 #define G_MAXOFFSET	G_MAXINT64
 
 
-#define GPOINTER_TO_INT(p)	((gint)   (p))
-#define GPOINTER_TO_UINT(p)	((guint)  (p))
+#define GPOINTER_TO_INT(p)	((gint)  (glong) (p))
+#define GPOINTER_TO_UINT(p)	((guint) (gulong) (p))
 
-#define GINT_TO_POINTER(i)	((gpointer)  (i))
-#define GUINT_TO_POINTER(u)	((gpointer)  (u))
+#define GINT_TO_POINTER(i)	((gpointer) (glong) (i))
+#define GUINT_TO_POINTER(u)	((gpointer) (gulong) (u))
 
 #ifdef NeXT /* @#%@! NeXTStep */
 # define g_ATEXIT(proc)	(!atexit (proc))
@@ -85,8 +85,8 @@ typedef gint64 goffset;
 #define g_memmove(dest,src,len) G_STMT_START { memmove ((dest), (src), (len)); } G_STMT_END
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 14
-#define GLIB_MICRO_VERSION 5
+#define GLIB_MINOR_VERSION 16
+#define GLIB_MICRO_VERSION 4
 
 #define G_OS_UNIX
 
@@ -122,7 +122,7 @@ typedef gint64 goffset;
 #endif
 
 #define G_HAVE_GNUC_VARARGS 1
-#define G_HAVE_GROWING_STACK 1
+#define G_HAVE_GROWING_STACK 0
 
 #define G_HAVE_GNUC_VISIBILITY 1
 #if defined(__SUNPRO_C) && (__SUNPRO_C >= 0x550)
@@ -140,13 +140,13 @@ struct _GStaticMutex
 {
   struct _GMutex *runtime_mutex;
   union {
-    char   pad[4];
+    char   pad[8];
     double dummy_double;
     void  *dummy_pointer;
     long   dummy_long;
   } static_mutex;
 };
-#define	G_STATIC_MUTEX_INIT	{ NULL, { { 0,0,0,0} } }
+#define	G_STATIC_MUTEX_INIT	{ NULL, { { 0,0,0,0,0,0,0,0} } }
 #define	g_static_mutex_get_mutex(mutex) \
   (g_thread_use_default_impl ? ((GMutex*) ((mutex)->static_mutex.pad)) : \
    g_static_mutex_get_mutex_impl_shortcut (&((mutex)->runtime_mutex)))
@@ -157,7 +157,7 @@ struct _GStaticMutex
 typedef union _GSystemThread GSystemThread;
 union _GSystemThread
 {
-  char   data[4];
+  char   data[8];
   double dummy_double;
   void  *dummy_pointer;
   long   dummy_long;
@@ -165,27 +165,27 @@ union _GSystemThread
 
 #define G_ATOMIC_OP_MEMORY_BARRIER_NEEDED 1
 
-#define GINT16_TO_BE(val)	((gint16) (val))
-#define GUINT16_TO_BE(val)	((guint16) (val))
-#define GINT16_TO_LE(val)	((gint16) GUINT16_SWAP_LE_BE (val))
-#define GUINT16_TO_LE(val)	(GUINT16_SWAP_LE_BE (val))
-#define GINT32_TO_BE(val)	((gint32) (val))
-#define GUINT32_TO_BE(val)	((guint32) (val))
-#define GINT32_TO_LE(val)	((gint32) GUINT32_SWAP_LE_BE (val))
-#define GUINT32_TO_LE(val)	(GUINT32_SWAP_LE_BE (val))
-#define GINT64_TO_BE(val)	((gint64) (val))
-#define GUINT64_TO_BE(val)	((guint64) (val))
-#define GINT64_TO_LE(val)	((gint64) GUINT64_SWAP_LE_BE (val))
-#define GUINT64_TO_LE(val)	(GUINT64_SWAP_LE_BE (val))
-#define GLONG_TO_LE(val)	((glong) GINT32_TO_LE (val))
-#define GULONG_TO_LE(val)	((gulong) GUINT32_TO_LE (val))
-#define GLONG_TO_BE(val)	((glong) GINT32_TO_BE (val))
-#define GULONG_TO_BE(val)	((gulong) GUINT32_TO_BE (val))
+#define GINT16_TO_LE(val)	((gint16) (val))
+#define GUINT16_TO_LE(val)	((guint16) (val))
+#define GINT16_TO_BE(val)	((gint16) GUINT16_SWAP_LE_BE (val))
+#define GUINT16_TO_BE(val)	(GUINT16_SWAP_LE_BE (val))
+#define GINT32_TO_LE(val)	((gint32) (val))
+#define GUINT32_TO_LE(val)	((guint32) (val))
+#define GINT32_TO_BE(val)	((gint32) GUINT32_SWAP_LE_BE (val))
+#define GUINT32_TO_BE(val)	(GUINT32_SWAP_LE_BE (val))
+#define GINT64_TO_LE(val)	((gint64) (val))
+#define GUINT64_TO_LE(val)	((guint64) (val))
+#define GINT64_TO_BE(val)	((gint64) GUINT64_SWAP_LE_BE (val))
+#define GUINT64_TO_BE(val)	(GUINT64_SWAP_LE_BE (val))
+#define GLONG_TO_LE(val)	((glong) GINT64_TO_LE (val))
+#define GULONG_TO_LE(val)	((gulong) GUINT64_TO_LE (val))
+#define GLONG_TO_BE(val)	((glong) GINT64_TO_BE (val))
+#define GULONG_TO_BE(val)	((gulong) GUINT64_TO_BE (val))
 #define GINT_TO_LE(val)		((gint) GINT32_TO_LE (val))
 #define GUINT_TO_LE(val)	((guint) GUINT32_TO_LE (val))
 #define GINT_TO_BE(val)		((gint) GINT32_TO_BE (val))
 #define GUINT_TO_BE(val)	((guint) GUINT32_TO_BE (val))
-#define G_BYTE_ORDER G_BIG_ENDIAN
+#define G_BYTE_ORDER G_LITTLE_ENDIAN
 
 #define GLIB_SYSDEF_POLLIN =1
 #define GLIB_SYSDEF_POLLOUT =4
